@@ -4,31 +4,34 @@
 
 from __future__ import unicode_literals
 
-import sys
-import os
-import urlparse
-import json
-import threading
-from multiprocessing import Queue
 import hashlib
-from collections import defaultdict, OrderedDict
+import json
 import logging
+import os
+import shutil
+import socket
+import sys
+import threading
+import time
 import traceback
+import urlparse
 from StringIO import StringIO
+from collections import defaultdict, OrderedDict
+from multiprocessing import Queue
 
-from mozlog.structured import structuredlog, commandline, stdadapter
-from mozlog.structured.handlers import StreamHandler
-from mozlog.structured.formatters import JSONFormatter
-from mozprocess import ProcessHandler
 import moznetwork
+from mozlog.structured import structuredlog, commandline, stdadapter
+from mozlog.structured.formatters import JSONFormatter
+from mozlog.structured.handlers import StreamHandler
+from mozprocess import ProcessHandler
 
-from testrunner import ManagerGroup
-import metadata
 import manifestexpected
-import wpttest
-import wptcommandline
 import manifestinclude
+import metadata
 import products
+import wptcommandline
+import wpttest
+from testrunner import ManagerGroup
 
 here = os.path.split(__file__)[0]
 
@@ -84,6 +87,10 @@ def do_test_relative_imports(test_root):
     import serve
 
 
+class TestEnvironmentError(Exception):
+    pass
+
+
 class TestEnvironment(object):
     def __init__(self, test_path, options):
         """Context manager that owns the test environment i.e. the http and
@@ -92,13 +99,28 @@ class TestEnvironment(object):
         self.server = None
         self.config = None
         self.options = options if options is not None else {}
+        self.files_to_restore = []
 
     def __enter__(self):
+        self.copy_required_files()
+
+        config = self.load_config()
+        serve.set_computed_defaults(config)
+
+        serve.logger = serve.default_logger("info")
+        self.config, self.servers = serve.start(config)
+        return self
+
+    def __exit__(self, exc_type, exc_val, exc_tb):
+        self.restore_files()
+        for scheme, servers in self.servers.iteritems():
+            for port, server in servers:
+                server.kill()
+
+    def load_config(self):
         default_config_path = os.path.join(self.test_path, "config.default.json")
         local_config_path = os.path.join(here, "config.json")
 
-        # TODO Move this into serve.py
-
         with open(default_config_path) as f:
             default_config = json.load(f)
 
@@ -106,17 +128,43 @@ class TestEnvironment(object):
             data = f.read()
             local_config = json.loads(data % self.options)
 
-        config = serve.merge_json(default_config, local_config)
-        serve.set_computed_defaults(config)
+        return serve.merge_json(default_config, local_config)
 
-        serve.logger = serve.default_logger("info")
-        self.config, self.servers = serve.start(config)
-        return self
+    def copy_required_files(self):
+        logger.info("Placing required files in server environment.")
+        for source, destination, copy_if_exists in [("testharness_runner.html", "", False),
+                                                    ("testharnessreport.js", "resources/", True)]:
+            source_path = os.path.join(here, source)
+            dest_path = os.path.join(self.test_path, destination, os.path.split(source)[1])
+            if os.path.exists(dest_path):
+                if copy_if_exists:
+                    self.files_to_restore.append(dest_path)
+                    shutil.copy2(dest_path, dest_path + ".orig")
+                else:
+                    continue
+            shutil.copy2(source_path, dest_path)
 
-    def __exit__(self, exc_type, exc_val, exc_tb):
+    def ensure_started(self):
+        time.sleep(2)
         for scheme, servers in self.servers.iteritems():
             for port, server in servers:
-                server.kill()
+                s = socket.socket()
+                try:
+                    s.connect((self.config["host"], port))
+                except socket.error:
+                    raise EnvironmentError("%s server on port %d failed to start" % (scheme, port))
+                finally:
+                    s.close()
+
+                if not server.is_alive():
+                    raise EnvironmentError("%s server on port %d failed to start" % (scheme, port))
+
+    def restore_files(self):
+        for path in self.files_to_restore:
+            if os.path.exists(path + ".orig"):
+                os.rename(path + ".orig", path)
+            else:
+                os.unlink(path)
 
 class TestChunker(object):
     def __init__(self, total_chunks, chunk_number):
@@ -382,18 +430,14 @@ def list_test_groups(tests_root, metadata_root, test_types, product, **kwargs):
     for item in sorted(test_loader.get_groups(test_types)):
         print item
 
-def run_tests(tests_root, metadata_root, prefs_root, test_types, binary=None,
-              processes=1, include=None, exclude=None, include_manifest=None,
-              capture_stdio=True, product="firefox", chunk_type="none",
-              total_chunks=1, this_chunk=1, timeout_multiplier=1,
-              repeat=1, **kwargs):
+def run_tests(tests_root, metadata_root, product, **kwargs):
     logging_queue = None
     logging_thread = None
     original_stdio = (sys.stdout, sys.stderr)
     test_queues = None
 
     try:
-        if capture_stdio:
+        if not kwargs["no_capture_stdio"]:
             logging_queue = Queue()
             logging_thread = LogThread(logging_queue, logger, "info")
             sys.stdout = LoggingWrapper(logging_queue, prefix="STDOUT")
@@ -404,44 +448,59 @@ def run_tests(tests_root, metadata_root, prefs_root, test_types, binary=None,
 
         run_info = wpttest.get_run_info(product, debug=False)
 
-        logger.info("Using %i client processes" % processes)
-
-        (browser_cls, get_browser_kwargs,
+        (check_args,
+         browser_cls, get_browser_kwargs,
          executor_classes, get_executor_kwargs,
          env_options) = products.load_product(product)
 
-        browser_kwargs = get_browser_kwargs(product, binary, prefs_root, **kwargs)
+        check_args(**kwargs)
+
+        browser_kwargs = get_browser_kwargs(**kwargs)
 
         unexpected_total = 0
 
         if "test_loader" in kwargs:
             test_loader = kwargs["test_loader"]
         else:
-            test_filter = TestFilter(include=include, exclude=exclude,
-                                     manifest_path=include_manifest)
+            test_filter = TestFilter(include=kwargs["include"], exclude=kwargs["exclude"],
+                                     manifest_path=kwargs["include_manifest"])
             test_loader = TestLoader(tests_root, metadata_root, test_filter, run_info)
 
+        logger.info("Using %i client processes" % kwargs["processes"])
+
         with TestEnvironment(tests_root, env_options) as test_environment:
+            try:
+                test_environment.ensure_started()
+            except TestEnvironmentError as e:
+                logger.critical("Error starting test environment: %s" % e.message)
+                raise
+
             base_server = "http://%s:%i" % (test_environment.config["host"],
                                             test_environment.config["ports"]["http"][0])
+            repeat = kwargs["repeat"]
             for repeat_count in xrange(repeat):
                 if repeat > 1:
                     logger.info("Repetition %i / %i" % (repeat_count + 1, repeat))
-                test_ids, test_queues = test_loader.queue_tests(test_types, chunk_type, total_chunks, this_chunk)
+
+                test_ids, test_queues = test_loader.queue_tests(kwargs["test_types"],
+                                                                kwargs["chunk_type"],
+                                                                kwargs["total_chunks"],
+                                                                kwargs["this_chunk"])
                 unexpected_count = 0
                 logger.suite_start(test_ids, run_info)
-                for test_type in test_types:
+                for test_type in kwargs["test_types"]:
                     tests_queue = test_queues[test_type]
 
                     executor_cls = executor_classes.get(test_type)
-                    executor_kwargs = get_executor_kwargs(base_server, timeout_multiplier)
+                    executor_kwargs = get_executor_kwargs(base_server,
+                                                          **kwargs)
 
                     if executor_cls is None:
                         logger.error("Unsupported test type %s for product %s" % (test_type, product))
                         continue
 
                     with ManagerGroup("web-platform-tests",
-                                      processes,
+                                      kwargs["processes"],
                                       browser_cls,
                                       browser_kwargs,
                                       executor_cls,
@@ -467,7 +526,7 @@ def run_tests(tests_root, metadata_root, prefs_root, test_types, binary=None,
             for queue in test_queues.itervalues():
                 queue.close()
         sys.stdout, sys.stderr = original_stdio
-        if capture_stdio and logging_queue is not None:
+        if not kwargs["no_capture_stdio"] and logging_queue is not None:
             logger.info("Closing logging queue")
             logging_queue.put(None)
             if logging_thread is not None:
